### R code from vignette source 'overview.Rnw'
### Encoding: ASCII

###################################################
### code chunk number 1: overview.Rnw:170-173
###################################################
library(psych)
data(sat.act) 
describe(sat.act)  #basic descriptive statistics


###################################################
### code chunk number 2: overview.Rnw:180-181
###################################################
describe.by(sat.act,sat.act$gender,skew=FALSE,ranges=FALSE) #basic descriptive statistics by a grouping variable.


###################################################
### code chunk number 3: overview.Rnw:186-190
###################################################
sa.mat <- describe.by(sat.act,list(sat.act$gender,sat.act$education),
 skew=FALSE,ranges=FALSE,mat=TRUE)
head(sa.mat)
tail(sa.mat)


###################################################
### code chunk number 4: overview.Rnw:198-201
###################################################
x <- matrix(1:120,ncol=10,byrow=TRUE)
new.x <- scrub(x,3:5,min=c(30,40,50),max=70,isvalue=45)
new.x


###################################################
### code chunk number 5: overview.Rnw:217-218
###################################################
pairs.panels(sat.act)


###################################################
### code chunk number 6: overview.Rnw:229-231
###################################################
data(affect)
pairs.panels(flat[15:18],bg=c("red","black","white","blue")[maps$Film],pch=21,main="Affect varies by movies (study 'flat')")


###################################################
### code chunk number 7: overview.Rnw:251-253
###################################################
data(epi.bfi)
error.bars.by(epi.bfi[,6:10],epi.bfi$epilie<4)


###################################################
### code chunk number 8: overview.Rnw:264-265
###################################################
error.bars.by(sat.act[5:6],sat.act$gender,bars=TRUE,labels=c("Male","Female"),ylab="SAT score",xlab="")


###################################################
### code chunk number 9: overview.Rnw:276-278
###################################################
data(bfi)
with(bfi,{bi.bars(age,gender,ylab="Age",main="Age by males and females")})


###################################################
### code chunk number 10: overview.Rnw:290-292
###################################################
data(bifactor)
cor.plot(Thurstone,color=TRUE,main="9 cognitive variables from Thurstone")


###################################################
### code chunk number 11: overview.Rnw:301-304
###################################################
circ <- sim.circ(24)
r.circ <- cor(circ)
cor.plot(r.circ,color=TRUE,zlim=c(-1,1),main="24 variables in a circumplex")


###################################################
### code chunk number 12: overview.Rnw:315-316
###################################################
corr.test(sat.act)


###################################################
### code chunk number 13: overview.Rnw:321-322
###################################################
r.test(50,.3)


###################################################
### code chunk number 14: overview.Rnw:326-327
###################################################
r.test(30,.4,.6)


###################################################
### code chunk number 15: overview.Rnw:332-333
###################################################
r.test(103,.4,.5,.1)


###################################################
### code chunk number 16: overview.Rnw:337-338
###################################################
r.test(103,.5,.6,.7,.5,.5,.8)  #steiger Case B 


###################################################
### code chunk number 17: overview.Rnw:344-345
###################################################
cortest(sat.act)


###################################################
### code chunk number 18: overview.Rnw:354-355
###################################################
draw.tetra()


###################################################
### code chunk number 19: overview.Rnw:424-426
###################################################
f3t <- fa(Thurstone,3,n.obs=213)
f3t 


###################################################
### code chunk number 20: overview.Rnw:444-448
###################################################
data(bifactor)
f3 <- fa(Thurstone,3,n.obs = 213,fm="pa")
f3o <- target.rot(f3)
f3o


###################################################
### code chunk number 21: overview.Rnw:463-466
###################################################
data(bifactor)
f3w <- fa(Thurstone,3,n.obs = 213,fm="wls")
print(f3w,cut=0,digits=3)


###################################################
### code chunk number 22: overview.Rnw:476-477
###################################################
plot(f3t)


###################################################
### code chunk number 23: overview.Rnw:487-488
###################################################
fa.diagram(f3t)


###################################################
### code chunk number 24: overview.Rnw:505-508
###################################################
data(bifactor)
p3p <-principal(Thurstone,3,n.obs = 213,rotate="Promax")
p3p


###################################################
### code chunk number 25: overview.Rnw:524-526
###################################################
om.h <- omega(Thurstone,n.obs=213,sl=FALSE)
op <- par(mfrow=c(1,1))


###################################################
### code chunk number 26: overview.Rnw:535-536
###################################################
om <- omega(Thurstone,n.obs=213)


###################################################
### code chunk number 27: overview.Rnw:561-563
###################################################
data(bfi)
ic <- iclust(bfi[1:25])


###################################################
### code chunk number 28: overview.Rnw:573-574
###################################################
summary(ic)  #show the results


###################################################
### code chunk number 29: overview.Rnw:597-599
###################################################
f4 <- fa(bfi[1:25],4,fm="pa")
factor.congruence(f4,ic)


###################################################
### code chunk number 30: overview.Rnw:603-604
###################################################
factor.congruence(list(f3t,f3o,om,p3p))


###################################################
### code chunk number 31: overview.Rnw:643-644
###################################################
vss <- vss(bfi[1:25],title="Very Simple Structure of a Big 5 inventory")


###################################################
### code chunk number 32: overview.Rnw:651-652
###################################################
vss


###################################################
### code chunk number 33: overview.Rnw:659-660
###################################################
fa.parallel(bfi[1:25],main="Parallel Analysis of a Big 5 inventory")


###################################################
### code chunk number 34: overview.Rnw:709-713
###################################################
set.seed(42)
r9 <- sim.hierarchical(n=500,raw=TRUE)$observed
round(cor(r9),2)
alpha(r9)


###################################################
### code chunk number 35: overview.Rnw:716-718
###################################################
keys <- c(1,-1,1,1,1,1,1)
alpha(attitude,keys)


###################################################
### code chunk number 36: overview.Rnw:722-724
###################################################
keys <- c(1,1,1,1,1,1,1)
alpha(attitude,keys)


###################################################
### code chunk number 37: overview.Rnw:730-732
###################################################
items <- sim.congeneric(N=500,short=FALSE,low=-2,high=2,categorical=TRUE) #500 responses to 4 discrete items
alpha(items$observed)  #item response analysis of congeneric measures


###################################################
### code chunk number 38: overview.Rnw:785-786
###################################################
om.9 <- omega(r9,title="9 simulated variables")


###################################################
### code chunk number 39: overview.Rnw:796-797
###################################################
om.9


###################################################
### code chunk number 40: overview.Rnw:802-803
###################################################
omegaSem(r9,n.obs=500)


###################################################
### code chunk number 41: overview.Rnw:809-810
###################################################
guttman(r9)


###################################################
### code chunk number 42: overview.Rnw:830-835
###################################################
 keys <- make.keys(nvars=28,list(Agree=c(-1,2:5),Conscientious=c(6:8,-9,-10),
 Extraversion=c(-11,-12,13:15),Neuroticism=c(16:20),
 Openness = c(21,-22,23,24,-25)),
 item.labels=colnames(bfi))
 keys


###################################################
### code chunk number 43: overview.Rnw:842-846
###################################################
 keys.1<- make.keys(10,list(Agree=c(-1,2:5),Conscientious=c(6:8,-9,-10)))
keys.2 <- make.keys(15,list(Extraversion=c(-1,-2,3:5),Neuroticism=c(6:10),
 Openness = c(11,-12,13,14,-15)))
 keys.25 <- super.matrix(keys.1,keys.2)


###################################################
### code chunk number 44: overview.Rnw:854-856
###################################################
 scores <- score.items(keys,bfi)
 scores


###################################################
### code chunk number 45: overview.Rnw:862-863
###################################################
pairs.panels(scores$scores)


###################################################
### code chunk number 46: overview.Rnw:875-878
###################################################
r.bfi <- cor(bfi,use="pairwise")
scales <- cluster.cor(keys,r.bfi)
summary(scales)


###################################################
### code chunk number 47: overview.Rnw:902-906
###################################################
set.seed(17)
d9 <- sim.irt(9,1000,-2.5,2.5,mod="normal") #dichotomous items
test <- irt.fa(d9$items)
test 


###################################################
### code chunk number 48: overview.Rnw:911-916
###################################################
op <- par(mfrow=c(3,1))
plot(test,type="ICC")
plot(test,type="IIC")
plot(test,type="test")
op <- par(mfrow=c(1,1))


###################################################
### code chunk number 49: overview.Rnw:925-928
###################################################
data(bfi)
e.irt <- irt.fa(bfi[11:15])
e.irt 


###################################################
### code chunk number 50: overview.Rnw:934-935
###################################################
plot(e.irt,type="IIC")


###################################################
### code chunk number 51: overview.Rnw:953-958
###################################################
data(sat.act)

C <- cov(sat.act,use="pairwise")
model1 <- lm(ACT~ gender + education + age, data=sat.act)
summary(model1)


###################################################
### code chunk number 52: overview.Rnw:961-963
###################################################
#compare with mat.regress
mat.regress(C,c(1:3),c(4:6), n.obs=700)


###################################################
### code chunk number 53: overview.Rnw:1042-1066
###################################################
xlim=c(0,10)
ylim=c(0,10)
plot(NA,xlim=xlim,ylim=ylim,main="Demontration of dia functions",axes=FALSE,xlab="",ylab="")
ul <- dia.rect(1,9,labels="upper left",xlim=xlim,ylim=ylim)
ll <- dia.rect(1,3,labels="lower left",xlim=xlim,ylim=ylim)
lr <- dia.ellipse(9,3,"lower right",xlim=xlim,ylim=ylim)
ur <- dia.ellipse(9,9,"upper right",xlim=xlim,ylim=ylim)
ml <- dia.ellipse(3,6,"middle left",xlim=xlim,ylim=ylim)
mr <- dia.ellipse(7,6,"middle right",xlim=xlim,ylim=ylim)
bl <- dia.ellipse(1,1,"bottom left",xlim=xlim,ylim=ylim)
br <- dia.rect(9,1,"bottom right",xlim=xlim,ylim=ylim)
dia.arrow(from=lr,to=ul,labels="right to left")
dia.arrow(from=ul,to=ur,labels="left to right")
dia.curved.arrow(from=lr,to=ll$right,labels ="right to left")
dia.curved.arrow(to=ur,from=ul$right,labels ="left to right")
dia.curve(ll$top,ul$bottom,"double")  #for rectangles, specify where to point 
dia.curved.arrow(mr,ur,"up")  #but for ellipses, just point to it.
dia.curve(ml,mr,"across")
dia.arrow(ur,lr,"top down")
dia.curved.arrow(br$top,lr$bottom,"up")
dia.curved.arrow(bl,br,"left to right")
dia.arrow(bl,ll$bottom)
dia.curved.arrow(ml,ll$right)
dia.curved.arrow(mr,lr$top)


###################################################
### code chunk number 54: overview.Rnw:1107-1108
###################################################
sessionInfo()


